<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=ast
// ** ne pas modifier le fichier **

return [

	// A
	'access_interface_graphique' => 'Tornar a la interfaz gráfica completa',
	'access_mode_texte' => 'Amosar l’interfaz simple en mou testu',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Iguar esti artículu',
	'admin_modifier_auteur' => 'Camudar esti autor',
	'admin_modifier_breve' => 'Camudar esta breve',
	'admin_modifier_mot' => 'Camudar esta pallabra-clave',
	'admin_modifier_rubrique' => 'Iguar la estaya',
	'admin_recalculer' => 'Recalcular esta páxina',
	'afficher_trad' => 'amosar les tornes',
	'alerte_maj_impossible' => '<b>¡Alerta!</b> El remocique de la base SQL a la versión @version@ nun ye posible, seique por un problema de permisos pa camudar la base de datos. Contauta col to agospiamientu web.',
	'alerte_modif_info_concourante' => 'ATENCIÓN: Esta información camudose n’otru llugar. El valor actual ye:',
	'analyse_xml' => 'Análisis XML',
	'annuler' => 'Anular',
	'antispam_champ_vide' => 'Esti campu tien que quedar vacíu:',
	'articles_recents' => 'Artículos más nuevos',
	'avis_archive_incorrect' => 'El ficheru d’archivu nun ye un ficheru de SPIP',
	'avis_archive_invalide' => 'el ficheru d’archivu nun ye válidu',
	'avis_attention' => '¡CUIDAU!',
	'avis_champ_incorrect_type_objet' => 'Nome de campu incorréutu @name@ pal oxetu de tipu @type@',
	'avis_colonne_inexistante' => 'La columna @col@ nun esiste',
	'avis_erreur' => 'Error: ver embaxo.',
	'avis_erreur_connexion' => 'Fallu de conexón',
	'avis_erreur_cookie' => 'problema de cookie',
	'avis_erreur_fonction_contexte' => 'Fallu de programación. Esta función nun tien que llamase n’esi contestu.',
	'avis_erreur_mysql' => 'Fallu de SQL',
	'avis_erreur_sauvegarde' => '¡Fallu na copia de seguridá (@type@ @id_objet@)!',
	'avis_erreur_visiteur' => 'Problema cola entrada al espaciu priváu',

	// B
	'barre_a_accent_grave' => 'Amestar una A mayúscula con acentu grave',
	'barre_aide' => 'Usa los atayos tipográficos para iguar meyor la presentación del testu',
	'barre_e_accent_aigu' => 'Amestar una E mayúscula con tilde',
	'barre_eo' => 'Amestar una E a la O',
	'barre_eo_maj' => 'Amestar una E cola O mayúscula',
	'barre_euro' => 'Amestar la marca €',
	'barre_gras' => 'Poner en {{negrina}}',
	'barre_guillemets' => 'Poner ente «comines»',
	'barre_guillemets_simples' => 'Poner ente comines de segundu nivel',
	'barre_intertitre' => 'Camudar a {{{inter-títulu}}}',
	'barre_italic' => 'Poner en {cursiva}',
	'barre_lien' => 'Camudar a [enllaz d’hipertestu->http://...]',
	'barre_lien_input' => 'Indica les señes del to enllaz. Pueden conseñase unes señes web na forma http://www.talsitiu.ast/direutoriu/ o sólo poner el númberu d’un artículu d’esti sitiu.',
	'barre_note' => 'Camudar en [[Nota de pie de páxina]]',
	'barre_paragraphe' => 'Crear un párrafu',
	'barre_quote' => '<quote>Citar un mensaxe</quote>',
	'bouton_changer' => 'Camudar',
	'bouton_chercher' => 'Restolar',
	'bouton_choisir' => 'Escoyer',
	'bouton_deplacer' => 'Mover',
	'bouton_download' => 'Descargar', # MODIF
	'bouton_enregistrer' => 'Guardar',
	'bouton_radio_desactiver_messagerie_interne' => 'Desactivar los mensaxes internos',
	'bouton_radio_envoi_annonces' => 'Unviar anuncies editoriales',
	'bouton_radio_non_envoi_annonces' => 'Nun unviar anuncies',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Nun unviar la llista de novedáes',
	'bouton_recharger_page' => 'recargar esta páxina',
	'bouton_telecharger' => 'Subir',
	'bouton_upload' => 'Subir', # MODIF
	'bouton_valider' => 'Validar',

	// C
	'cal_apresmidi' => 'tardi',
	'cal_jour_entier' => 'día enteru',
	'cal_matin' => 'mañana',
	'cal_par_jour' => 'calendariu por día',
	'cal_par_mois' => 'calendariu por mes',
	'cal_par_semaine' => 'calendariu por selmana',
	'choix_couleur_interface' => 'color ',
	'choix_interface' => 'escoyeta de l’interfaz',
	'colonne' => 'Columna',
	'confirm_changer_statut' => 'Atención, acabes de pidir el cambéu de l’estáu d’esti elementu. ¿Quiés continuar?',
	'correcte' => 'correuta',

	// D
	'date_aujourdhui' => 'güei',
	'date_avant_jc' => 'aC',
	'date_dans' => 'en @delai@',
	'date_de_mois_1' => '@j@ de @nommois@',
	'date_de_mois_10' => '@j@ d’@nommois@',
	'date_de_mois_11' => '@j@ de @nommois@',
	'date_de_mois_12' => '@j@ d’@nommois@',
	'date_de_mois_2' => '@j@ de @nommois@',
	'date_de_mois_3' => '@j@ de @nommois@',
	'date_de_mois_4' => '@j@ d’@nommois@',
	'date_de_mois_5' => '@j@ de @nommois@',
	'date_de_mois_6' => '@j@ de @nommois@',
	'date_de_mois_7' => '@j@ de @nommois@',
	'date_de_mois_8' => '@j@ d’@nommois@',
	'date_de_mois_9' => '@j@ de @nommois@',
	'date_demain' => 'mañana',
	'date_fmt_heures_minutes' => '@h@h.@m@min.',
	'date_fmt_jour_heure' => '@jour@ a les @heure@',
	'date_fmt_jour_mois' => '@jour@ de @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ de @nommois@ de @annee@',
	'date_fmt_mois_annee' => '@nommois@ de @annee@',
	'date_fmt_nomjour_date' => 'el @nomjour@ @date@',
	'date_heures' => 'hores',
	'date_hier' => 'ayeri',
	'date_il_y_a' => 'hai @delai@',
	'date_jnum1' => '1u',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'domingu',
	'date_jour_1_abbr' => 'dom.',
	'date_jour_1_initiale' => 'd.',
	'date_jour_2' => 'llunes',
	'date_jour_2_abbr' => 'llu.',
	'date_jour_2_initiale' => 'l.',
	'date_jour_3' => 'martes',
	'date_jour_3_abbr' => 'mar.',
	'date_jour_3_initiale' => 'm.',
	'date_jour_4' => 'miércoles',
	'date_jour_4_abbr' => 'mié.',
	'date_jour_4_initiale' => 'm.',
	'date_jour_5' => 'xueves',
	'date_jour_5_abbr' => 'xue.',
	'date_jour_5_initiale' => 'x.',
	'date_jour_6' => 'vienres',
	'date_jour_6_abbr' => 'vie.',
	'date_jour_6_initiale' => 'v.',
	'date_jour_7' => 'sábadu',
	'date_jour_7_abbr' => 'sáb.',
	'date_jour_7_initiale' => 's.',
	'date_jours' => 'díes',
	'date_minutes' => 'minutos',
	'date_mois' => 'meses',
	'date_mois_1' => 'xineru',
	'date_mois_10' => 'ochobre',
	'date_mois_11' => 'payares',
	'date_mois_12' => 'avientu',
	'date_mois_2' => 'febreru',
	'date_mois_3' => 'marzu',
	'date_mois_4' => 'abril',
	'date_mois_5' => 'mayu',
	'date_mois_6' => 'xunu',
	'date_mois_7' => 'xunetu',
	'date_mois_8' => 'agostu',
	'date_mois_9' => 'setiembre',
	'date_saison_1' => 'iviernu',
	'date_saison_2' => 'primavera',
	'date_saison_3' => 'branu',
	'date_saison_4' => 'seronda',
	'date_secondes' => 'segundos',
	'date_semaines' => 'selmanes',
	'date_un_mois' => 'mes',
	'date_une_heure' => 'hora',
	'date_une_minute' => 'minutu',
	'date_une_seconde' => 'segundu',
	'date_une_semaine' => 'selmana',
	'dirs_commencer' => 'pa entamar dafechu la instalación',
	'dirs_preliminaire' => 'Previo: <b>Iguar los permisos d’accesu</b>',
	'dirs_probleme_droits' => 'Problema colos permisos d’accesu',
	'dirs_repertoires_absents' => '<p><b>Nun s’atoparon los direutorios siguientes:</b></p><ul>@bad_dirs@</ul>
  <p>Ye probable qu’el problema seya por cuenta d’una equivocación coles mayúscules o minúscules.
  Comprueba que les minúscules y mayúscules d’estos direutorios concasen bien coles que s’amuesen
  enriba; si nun ye’l casu, renoma los direutorios col to programa de FTP pa iguar el fallu.</p>
  <p>De magar fechu esti cambéu, vas poder ',
	'dirs_repertoires_suivants' => '<p><b>Los direutorios siguientes nun son accesibles pa escritura:</b></p> <ul>@bad_dirs@</ul>
  <p>Pa igualo, usa el to cliente FTP pa reglar los permisos d’accesu de caún
  d’estos direutorios. El procesu esplícase en detalle na guía d’asitiamientu.</p>
  <p>De magar fechu el cambéu, vas poder ',
	'double_occurrence' => 'Ocurrencia doble de @balise@',

	// E
	'en_cours' => 'en cursu',
	'envoi_via_le_site' => 'Unviu mandándose del sitiu',
	'erreur' => 'Error',
	'erreur_balise_non_fermee' => 'cabera baliza nun pesllada:',
	'erreur_texte' => 'fallu(os)',
	'etape' => 'Etapa',

	// F
	'fichier_introuvable' => 'Nun s’alcuentra el ficheru @fichier@', # MODIF
	'form_auteur_confirmation' => 'Confirma les tos señes de corréu',
	'form_auteur_email_modifie' => 'Se camudaron les tos señes de corréu.',
	'form_auteur_envoi_mail_confirmation' => 'Vien d’unviase un corréu electrónicu de confirmación a @email@. Tendrás de visitar la direición Web qu’apaez nesi corréu pa validar les tos señes de corréu.',
	'form_auteur_mail_confirmation' => 'Bones,

Vienes de pidir que camuden les tos señes de corréu.
Pa confirmar les señes nueves, val con que te coneutes a
les señes darréu (d’otra miente, el cambéu de señes
s’encaboxará) :

    @url@
',
	'form_deja_inscrit' => 'Ya tas apuntáu.',
	'form_email_non_valide' => 'Les señes de corréu electrónicu nun son válides.',
	'form_forum_access_refuse' => 'Ya nun ties accesu a esti sitiu.',
	'form_forum_bonjour' => 'Hola, @nom@,',
	'form_forum_email_deja_enregistre' => 'Estes señes de corréu electrónicu ya tan rexistráes; poro, puedes usar la to contraseña normal.',
	'form_forum_identifiant_mail' => 'La to nueva identificación ta acabante d’unviase por email.',
	'form_forum_identifiants' => 'Identificación personal',
	'form_forum_indiquer_nom_email' => 'Indica equí el to nome y les tos señes d’email. La to identificación personal va llegate de secute por corréu ellectrónicu.',
	'form_forum_login' => 'login:',
	'form_forum_message_auto' => '(esti ye un mensaxe automáticu)',
	'form_forum_pass' => 'contraseña:',
	'form_forum_probleme_mail' => 'Problema col corréu: nun pudo mandase la identificación.',
	'form_forum_voici1' => 'Esta ye la to identificación pa que puedas participar dafechu
nel sitiu "@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'Esta ye la to identificación pa proponer artículos nel
sitiu "@nom_site_spip@" (@adresse_login@):',
	'form_indiquer_email' => 'Pon les tos señes de corréu electrónicu.',
	'form_indiquer_nom' => 'Indica el to nome.',
	'form_indiquer_nom_site' => 'Indica el nome del to sitiu Web.',
	'form_pet_deja_enregistre' => 'Esti sitiu ya ta rexistráu',
	'form_pet_signature_pasprise' => 'La to firma nun se tuvo en cuenta.',
	'form_prop_confirmer_envoi' => 'Confirmar l’unvíu',
	'form_prop_description' => 'Descripción/comentariu',
	'form_prop_enregistre' => 'La to propuesta quedó rexistrada, apaecerá en llínia tres de la validación polos responsables d’esti sitiu.', # MODIF
	'form_prop_envoyer' => 'Unviar un mensaxe',
	'form_prop_indiquer_email' => 'Hai qu’indicar unes señes d’email válides',
	'form_prop_indiquer_nom_site' => 'Hai qu’indicar el nome del sitiu.',
	'form_prop_indiquer_sujet' => 'Hai qu’indicar un asuntu',
	'form_prop_message_envoye' => 'Mensaxe unviáu',
	'form_prop_non_enregistre' => 'La to propuesta nun quedó rexistrada.',
	'form_prop_sujet' => 'Asuntu',
	'form_prop_url_site' => 'Señes (URL) del sitiu', # MODIF
	'forum_non_inscrit' => 'Nun tas apuntáu, o les tos señes o contraseña tan equivocáos.',
	'forum_par_auteur' => 'por @auteur@',
	'forum_titre_erreur' => 'Error...',

	// I
	'ical_texte_rss_articles' => 'El ficheru «backend» de los artículos d’esti sitiu alcuéntrase na direición:',
	'ical_texte_rss_articles2' => 'Lo mesmo puedes alcontrar ficheros «backend» pa los artículos de cada estaya d’esti sitiu:',
	'ical_texte_rss_breves' => 'Amás esiste un ficheru que contién les breves del sitiu. Escribiendo un númberu d’estaya, tendrás namái les breves d’esa estaya.',
	'icone_a_suivre' => 'A siguir',
	'icone_admin_site' => 'Alministración del sitiu',
	'icone_agenda' => 'Axenda',
	'icone_aide_ligne' => 'Aida',
	'icone_articles' => 'Artículos',
	'icone_auteurs' => 'Autores',
	'icone_brouteur' => 'Ñavegación rápida',
	'icone_configuration_site' => 'Configuración',
	'icone_configurer_site' => 'Configurar esti sitiu',
	'icone_creer_nouvel_auteur' => 'Crear un autor nuevu',
	'icone_creer_rubrique' => 'Crear una estaya',
	'icone_creer_sous_rubrique' => 'Crear una so-estaya',
	'icone_deconnecter' => 'Desconeutase',
	'icone_discussions' => 'Discutinios',
	'icone_doc_rubrique' => 'Documentos de les estayes',
	'icone_ecrire_article' => 'Escribir un artículu nuevu',
	'icone_edition_site' => 'Edición',
	'icone_gestion_langues' => 'Xestión de les llingües',
	'icone_informations_personnelles' => 'Información personal',
	'icone_interface_complet' => 'interfaz completa',
	'icone_interface_simple' => 'Interfaz simplificada',
	'icone_maintenance_site' => 'Mantenimientu del sitiu',
	'icone_messagerie_personnelle' => 'Mensaxería personal',
	'icone_repartition_debut' => 'Amosar el repartu dende l’entamu',
	'icone_rubriques' => 'Estayes',
	'icone_sauver_site' => 'Copia de seguridá del sitiu',
	'icone_site_entier' => 'El sitiu enteru',
	'icone_sites_references' => 'Sitios referenciaos',
	'icone_statistiques' => 'Estadístiques del sitiu',
	'icone_suivi_activite' => 'Siguir l’actividá del sitiu',
	'icone_suivi_actualite' => 'Evolución del sitiu',
	'icone_suivi_pettions' => 'Siguir/xestionar les solicitudes',
	'icone_suivi_revisions' => 'Cambéos de los artículos',
	'icone_supprimer_document' => 'Desaniciar esti documentu',
	'icone_supprimer_image' => 'Desaniciar esta imaxen',
	'icone_tous_articles' => 'Tolos artículos de to',
	'icone_tous_auteur' => 'Tolos autores',
	'icone_tous_visiteur' => 'Tolos visitantes',
	'icone_visiter_site' => 'Ver el sitiu públicu',
	'icone_voir_en_ligne' => 'Ver en llinia',
	'img_indisponible' => 'imaxe non disponible',
	'impossible' => 'imposible',
	'info_a_suivre' => 'A SIGUIR»',
	'info_acces_interdit' => 'Accesu torgáu',
	'info_acces_refuse' => 'Accesu refugáu',
	'info_action' => 'Aición: @action@',
	'info_administrer_rubriques' => 'Puedes alministrar esta estaya y les dependientes d’ella',
	'info_adresse_non_indiquee' => '¡Nun indicasti qué señes hai que prebar!',
	'info_aide' => 'AIDA:',
	'info_ajouter_mot' => 'Amestar esta pallabra',
	'info_annonce' => 'ANUNCIU',
	'info_annonces_generales' => 'Anuncios xenerales:',
	'info_article_propose' => 'Artículu propuestu',
	'info_article_publie' => 'Artículu espublizáu',
	'info_article_redaction' => 'Artículu en cursu de redaición',
	'info_article_refuse' => 'Artículu refugáu',
	'info_article_supprime' => 'Artículu desaniciáu',
	'info_articles' => 'Artículos',
	'info_articles_a_valider' => 'Los artículos por validar',
	'info_articles_nb' => '@nb@ artículos',
	'info_articles_proposes' => 'Artículos propuestos',
	'info_articles_un' => '1 artículu',
	'info_auteurs_nombre' => 'autor(es):',
	'info_authentification_ftp' => 'Autentificación (per FTP).',
	'info_breves_2' => 'breves',
	'info_breves_nb' => '@nb@ breves',
	'info_breves_un' => '1 breve',
	'info_connexion_refusee' => 'Conexón refugada',
	'info_contact_developpeur' => 'Ponte en contautu con un desendolcador.', # MODIF
	'info_contenance' => 'Esti sitiu contien:',
	'info_contribution' => 'contribuciones del foru', # MODIF
	'info_copyright' => '@spip@ ye un programa llibre distribuyíu @lien_gpl@.',
	'info_copyright_doc' => 'Pa más información, dir al sitiu <a href="@spipnet@">http://www.spip.net/</a>.', # MODIF
	'info_copyright_gpl' => 'so llicencia GPL',
	'info_cours_edition' => 'Los tos artículos en cursu de redaición', # MODIF
	'info_creer_repertoire' => 'Debes crear un ficheru o un direutoriu nomáu:',
	'info_creer_repertoire_2' => 'dientro’l direutoriu <b>@repertoire@</b>, y llueu:',
	'info_creer_vignette' => 'creación automática de la viñeta',
	'info_deplier' => 'Desplegar',
	'info_descriptif_nombre' => 'descripción(es):',
	'info_description' => 'Descripción:',
	'info_description_2' => 'Descripción:',
	'info_dimension' => 'Dimensiones:',
	'info_documents_nb' => '@nb@ documentos',
	'info_documents_un' => '1 documentu',
	'info_ecire_message_prive' => 'Escribir un mensaxe priváu',
	'info_email_invalide' => 'Señes d’email non válides.',
	'info_en_cours_validation' => 'Los tos artículos en cursu de redaición',
	'info_en_ligne' => 'Actualmente en llinia:',
	'info_envoyer_message_prive' => 'Unviar un mensaxe priváu a esti autor',
	'info_erreur_requete' => 'Fallu na consulta:',
	'info_erreur_squelette2' => 'Nun hai denguna cadarma <b>@fichier@</b> disponible...',
	'info_erreur_systeme' => 'Fallu del sistema (errno @errsys@)',
	'info_erreur_systeme2' => 'El discu duru puede tar enllenu, o la base de datos dañada.<br />
<span style="color:red;">Tenta <a href=\'@script@\'>iguar la base</a>, o ponte en contautu col to agospiamientu.</span>',
	'info_fini' => '¡Acabose!',
	'info_format_image' => 'Formatos d’imaxe que pueden utilizase pa crear les viñetes: @gd_formats@.',
	'info_format_non_defini' => 'formatu nun definíu',
	'info_grand_ecran' => 'Pantalla completa',
	'info_image_aide' => 'AIDA',
	'info_image_process_titre' => 'Metodo de fabricación de les viñetes',
	'info_impossible_lire_page' => '<b>¡Fallu!</b> Nun ye posible lleer la páxina <tt><html>@test_proxy@</html></tt> al traviés del proxy ',
	'info_installation_systeme_publication' => 'Instalación del sistema d’espublizamientu...',
	'info_installer_documents' => 'Puedes instalar automáticamente tolos documentos contenios nel direutoriu @upload@.',
	'info_installer_ftp' => 'Como alministrador, puedes instalar ficheros (per FTP) nel direutoriu @upload@ pa poder lluéu seleicionalos direutamente equí.', # MODIF
	'info_installer_images' => 'Puedes instalar imaxes nos formatos JPEG, GIF y PNG.',
	'info_installer_images_dossier' => 'Instalar imáxenes nel direutoriu @upload@ pa poder seleicionales equí.',
	'info_interface_complete' => 'interfaz completa',
	'info_interface_simple' => 'Interfaz simplificada',
	'info_joindre_document_article' => 'Pues amesta-y a esti artículu documentos de tipu',
	'info_joindre_document_rubrique' => 'Pues amestar na estaya documentos de tipu',
	'info_joindre_documents_article' => 'Pues amesta-y al to artículu documentos de tipu:',
	'info_l_article' => 'l’artículu',
	'info_la_breve' => 'la breve',
	'info_la_rubrique' => 'la estaya',
	'info_langue_principale' => 'Llingua principal del sitiu',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ píxeles',
	'info_les_auteurs_1' => 'por @les_auteurs@',
	'info_logo_format_interdit' => 'Sólo tan autorizáos los formatos @formats@ pa los logos.',
	'info_logo_max_poids' => 'Los logos han tener obligatoriamente menos de @maxi@ (el ficheru tien @actuel@).',
	'info_mail_fournisseur' => 'el_to_nome@de.correu.ast',
	'info_message_2' => 'MENSAXE',
	'info_message_supprime' => 'MENSAXE DESANICIÁU',
	'info_messages_nb' => '@nb@ mensaxes',
	'info_messages_un' => '1 mensaxe',
	'info_mise_en_ligne' => 'Fecha d’espublizamientu:',
	'info_modification_parametres_securite' => 'cambéos de los parámetros de seguridá',
	'info_mois_courant' => 'A lo llargo d’esti mes:',
	'info_mot_cle_ajoute' => 'La pallabra-clave darréu amestóse a',
	'info_multi_herit' => 'Llíngua por omisión',
	'info_multi_langues_soulignees' => 'Les <u>llíngües solliñáes</u> beneficiense de la traducción de tolos testos de la interfaz. Si seleiciones estes llíngües, van traducise automáticamente abondos elementos del sitiu públicu (feches, formularios). Pa les llíngües non solliñáes, estos elementos apaecerán na llingua principal del sitiu.', # MODIF
	'info_multilinguisme' => 'Multillingüismu',
	'info_nom_non_utilisateurs_connectes' => 'El to nome nun apaez na llista d’usuarios coneutaos.', # MODIF
	'info_nom_utilisateurs_connectes' => 'El to nome apaez na llista d’usuarios coneutáos.', # MODIF
	'info_nombre_en_ligne' => 'En llinia agora:',
	'info_non_resultat' => 'Dengún resultáu pa "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Nun tas usando la mensaxería interna d’esti sitiu.',
	'info_nouveau_message' => 'TIENES UN MENSAXE NUEVU',
	'info_nouveaux_messages' => 'TIENES @total_messages@ MENSAXES NUEVOS',
	'info_numero_abbreviation' => 'N° ',
	'info_obligatoire' => 'Esta información ye obligatoria',
	'info_pense_bete' => 'RECORDATORIU',
	'info_petit_ecran' => 'Pantalla pequeña',
	'info_petition_close' => 'Solicitú pesllada',
	'info_pixels' => 'píxels',
	'info_plusieurs_mots_trouves' => 'Alcontráronse delles pallabres-clave pa "@cherche_mot@":',
	'info_portfolio_automatique' => 'Maletu automáticu:',
	'info_premier_resultat' => '[@debut_limit@ primeros resultaos de @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ primeros resultaos de @total@]',
	'info_propose_1' => '[@nom_site_spip@] Propuesta: @titre@',
	'info_propose_2' => 'Artículu propuestu
------------------',
	'info_propose_3' => 'L’artículu "@titre@" vien de proponese pa ser espublizáu.',
	'info_propose_4' => 'Quedes convidáu a consultalu y a dar la to opinión',
	'info_propose_5' => 'nel foru que tien axuntu. Tiéneslu disponible n’estes señes:',
	'info_publie_01' => 'L’artículu "@titre@" quedó validáu por @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLICÁU: @titre@',
	'info_publie_2' => 'Artículu publicáu
--------------',
	'info_rechercher' => 'Restolar',
	'info_rechercher_02' => 'Restolar:',
	'info_remplacer_vignette' => 'Cambear la viñeta por omisión por un logo personalizáu:',
	'info_rubriques_nb' => '@nb@ seiciónes',
	'info_rubriques_un' => '1 seición',
	'info_sans_titre_2' => 'ensin títulu',
	'info_selectionner_fichier' => 'Puedes escoyer un ficheru del direutoriu @upload@',
	'info_selectionner_fichier_2' => 'Escueye un ficheru:',
	'info_sites_nb' => '@nb@ sitios',
	'info_sites_un' => '1 sitiu',
	'info_supprimer_vignette' => 'desaniciar la viñeta',
	'info_symbole_bleu' => 'La marca <b>azul</b> indica un <b>recordatoriu</b>: ye un mensaxe pal to usu personal.',
	'info_symbole_jaune' => 'La marca <b>mariella</b> indica una <b>anuncia pa tolos redactores</b>: puede modificase por tolos alministradores, y ye visible por tolos redactores.', # MODIF
	'info_symbole_vert' => 'La marca <b>verde</b> indica los <b>mensaxes intercambeaos con otros usuarios</b> del sitiu.', # MODIF
	'info_telecharger_nouveau_logo' => 'Subir un logo nuevu:',
	'info_telecharger_ordinateur' => 'Subir dende’l to ordenador:',
	'info_tous_resultats_enregistres' => '[tolos resultaos tan grabaos]',
	'info_tout_afficher' => 'Amosalo too',
	'info_travaux_texte' => 'Esti sitiu nun ta iguao tovía. Torna más tarde...',
	'info_travaux_titre' => 'Sitiu n’obres',
	'info_trop_resultat' => 'Hai demasiaos resultaos pa "@cherche_mot@"; tienes que afinar meyor los criterios.',
	'info_utilisation_messagerie_interne' => 'Tas usando la mensaxería interna d’esti sitiu.',
	'info_valider_lien' => 'validar esti enllaz',
	'info_verifier_image' => ', has comprobar que les tos imaxes tresfirieranse correutamente.',
	'info_vignette_defaut' => 'Viñeta por omisión',
	'info_vignette_personnalisee' => 'Viñeta personalizada',
	'info_visite' => 'visita:',
	'info_vos_rendez_vous' => 'Aconceyamientos pendientes',
	'infos_vos_pense_bete' => 'Los tos recordatorios',

	// L
	'lien_afficher_icones_seuls' => 'Amosar namái los iconos',
	'lien_afficher_texte_icones' => 'Amosar los iconos y el testu',
	'lien_afficher_texte_seul' => 'Amosar sólo el testu',
	'lien_liberer' => 'lliberar',
	'lien_liberer_tous' => 'lliberar estos artículos', # MODIF
	'lien_nouvea_pense_bete' => 'RECORDATORIU NUEVU',
	'lien_nouveau_message' => 'MENSAXE NUEVU',
	'lien_nouvelle_annonce' => 'ANUNCIU NUEVU',
	'lien_petitions' => 'SOLICITÚ',
	'lien_popularite' => 'popularidá: @popularite@%',
	'lien_racine_site' => 'RAÍZ DEL SITIU',
	'lien_reessayer' => 'retentar',
	'lien_repondre_message' => 'Responder a esti mensaxe',
	'lien_supprimer' => 'desaniciar',
	'lien_tout_afficher' => 'Amosalo too',
	'lien_visite_site' => 'visitar esti sitiu',
	'lien_visites' => '@visites@ visites',
	'lien_voir_auteur' => 'Ver esti autor',
	'ligne' => 'Llinia',
	'login' => 'Conexón',
	'login_acces_prive' => 'accesu a l’espaciu priváu',
	'login_autre_identifiant' => 'coneutase con otru alcuñu',
	'login_cookie_accepte' => 'Ties que regular el to ñavegador pa que les acepte (polo menos pa esti sitiu).',
	'login_cookie_oblige' => 'Pa identificate de mou seguru nesti sitiu, ties que aceptar les cookies.',
	'login_deconnexion_ok' => 'Fecha la desconexón.',
	'login_erreur_pass' => 'Fallu de contraseña.',
	'login_espace_prive' => 'espaciu priváu',
	'login_identifiant_inconnu' => 'L’alcuñu «@login@» ye desconocíu.',
	'login_login' => 'Nome d’usuariu:',
	'login_login2' => 'Login (alcuñu de conexón al sitiu):', # MODIF
	'login_login_pass_incorrect' => '(Login o contraseña incorreutu.)',
	'login_motpasseoublie' => '¿escaecisti la contraseña?',
	'login_non_securise' => 'Atención, esti formulariu nun ye seguru.
   Si nun quies que la to contraseña pueda
   interceutase pel camín, tienes qu’activar
   Javascript nel to ñavegador y',
	'login_nouvelle_tentative' => 'Nuevu intentu',
	'login_par_ici' => 'Tas rexistráu... per equí...',
	'login_pass2' => 'Contraseña:',
	'login_preferez_refuser' => '<b>Si quiés más refugar les cookies</b>, tenemos disponible otru métodu de conexón (enforma menos seguru):',
	'login_recharger' => 'recargar esta páxina',
	'login_rester_identifie' => 'Quedar identificáu pa dellos díes', # MODIF
	'login_retour_public' => 'Tornar pal sitiu públicu',
	'login_retour_site' => 'Tornar pal sitiu públicu',
	'login_retoursitepublic' => 'tornar pal sitiu públicu',
	'login_securise' => 'Conexón asegurada',
	'login_sinscrire' => 'inscribise', # MODIF
	'login_test_navigateur' => 'preba de ñavegador/reconexón',
	'login_verifiez_navigateur' => '(Verifica dafechu que’l ñavegador nun s’alcuerde de la to contraseña...)',

	// M
	'masquer_colonne' => 'Tapecer esta columna',
	'masquer_trad' => 'tapecer les traducciones',
	'module_fichiers_langues' => 'Archivos de llingua',

	// N
	'navigateur_pas_redirige' => 'Si el to ñavegador nun te redirixe, calca equí pa continuar.',
	'numero' => 'Númberu',

	// O
	'occurence' => 'Ocurrencia',
	'onglet_affacer_base' => 'Desaniciar la base',
	'onglet_auteur' => 'L’autor',
	'onglet_contenu_site' => 'Conteníu del sitiu',
	'onglet_evolution_visite_mod' => 'Evolución',
	'onglet_fonctions_avances' => 'Funciones avanzáes',
	'onglet_informations_personnelles' => 'Información personal',
	'onglet_interactivite' => 'Interactividá',
	'onglet_messagerie' => 'Mensaxería',
	'onglet_repartition_rubrique' => 'Repartío por estayes',
	'onglet_save_restaur_base' => 'Sofitar/restaurar la base',
	'onglet_vider_cache' => 'Vaciar la caché',

	// P
	'pass_choix_pass' => 'Escueye la nueva contraseña:',
	'pass_erreur' => 'Error',
	'pass_erreur_acces_refuse' => '<b>Error:</b> ya nun tienes accesu a esti sitiu.',
	'pass_erreur_code_inconnu' => '<b>Error:</b> esti códigu nun correspuende a dengún visitante que tenga accesu a esti sitiu.', # MODIF
	'pass_erreur_non_enregistre' => '<b>Error:</b> les señes <tt>@email_oubli@</tt> nun tan rexistráes n’esti sitiu.',
	'pass_erreur_non_valide' => '<b>Error:</b> ¡estes señes <tt>@email_oubli@</tt> nun son válides!',
	'pass_erreur_probleme_technique' => '<b>Error:</b> por cuenta d’un problema téunicu, nun pudo mandase l’email.',
	'pass_espace_prive_bla' => 'L’espaciu priváu d’esti sitiu ta abiertu pa lo
  visitantes tres d’inscribise. Desque te rexistres,
  vas poder consultar los artículos en cursu de redaición,
  proponer artículos y participar en tolos foros.', # MODIF
	'pass_forum_bla' => 'Pedisti intervenir nun foru acutao
  pa los visitantes rexistraos.', # MODIF
	'pass_indiquez_cidessous' => 'Escribe embaxo les señes d’email coles que
   teas rexistráu. Vas recibir un email
   nel que te indicamos los pasos a dar
   pa volver a tener accesu.',
	'pass_mail_passcookie' => '(esti ye un mensaxe automáticu)
Pa volver a tener accesu al sitiu
@nom_site_spip@ (@adresse_site@)

Ties que dir a les siguientes señes:

    @sendcookie@

Agora vas poder escoyer una contraseña nueva
pa volver a coneutate al sitiu.

', # MODIF
	'pass_mot_oublie' => 'Contraseña escaecida',
	'pass_nouveau_enregistre' => 'La nueva contraseña quedó rexistrada.',
	'pass_nouveau_pass' => 'Contraseña nueva',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Contraseña escaecida',
	'pass_quitter_fenetre' => 'Zarrar esta ventana',
	'pass_rappel_login' => 'Recuerda: la to identidá (login) ye « @login@ ».',
	'pass_recevoir_mail' => 'Vas recibir un email que te indica cómo volver a tener accesu al sitiu.', # MODIF
	'pass_retour_public' => 'Volver pal sitiu públicu',
	'pass_rien_a_faire_ici' => 'Nun hai qué facer equí.',
	'pass_vousinscrire' => 'Apuntate a esti sitiu',
	'precedent' => 'anterior',
	'previsualisation' => 'Güeyada',
	'previsualiser' => 'Preagüeyar',

	// R
	'retour' => 'Tornar',

	// S
	'spip_conforme_dtd' => 'SPIP considera q’esti documentu ta conforme col so DOCTYPE:',
	'squelette' => 'cadarma',
	'squelette_inclus_ligne' => 'cadarma incluyía, llínia',
	'squelette_ligne' => 'cadarma, llínia',
	'stats_visites_et_popularite' => '@visites@ visites; popularidá: @popularite@',
	'suivant' => 'siguiente',

	// T
	'taille_ko' => '@taille@ KB',
	'taille_mo' => '@taille@ MB',
	'taille_octets' => '@taille@ bytes',
	'taille_octets_bi' => '@taille@ bytes',
	'texte_actualite_site_1' => 'Cuando yá t’afayes cola interfaz, puedes calcar en «',
	'texte_actualite_site_2' => 'interfaz completa',
	'texte_actualite_site_3' => '» pa amosar más posibilidáes.',
	'texte_creation_automatique_vignette' => 'La creación automática de miniatures de vista previa ta activa nesti sitiu. Si instales dende esti formulariu imáxenes en formatu(os) @gd_formats@, elles van acompañase d’una miniatura con un tamañu máximu de @taille_preview@ pixels.',
	'texte_documents_associes' => 'Los siguientes documentos tan asociaos al artículu,
    pero nun tan enxertaos direutamente
    Dependiendo de la compaxinación del sitiu públicu,
    podrán apaecer en forma de documentos axuntos.',
	'texte_erreur_mise_niveau_base' => 'Error mientres se adautaba la base de datos.
  La imaxen <b>@fichier@</b> nun se pasó (artículu @id_article@).
  Acuérdate d’esta referencia, vuelve a probar la
  adautación, y llueu mira si les imáxenes apaecen
  siempre nos artículos.',
	'texte_erreur_visiteur' => 'Acabes de tentar la entrada nel espaciu priváu con un login que nun lo permite.',
	'texte_inc_auth_1' => 'Identificástete col nome
<b>@auth_login@</b>, pero ésti nun esiste na base.
Intenta',
	'texte_inc_auth_2' => 'reconeutar',
	'texte_inc_auth_3' => ', tres de q’hayas, nel so casu, zarráo y
  vuelto a abrir el to ñavegador.',
	'texte_inc_config' => 'Les igües feches nestes páxines influyen abondo nel
 funcionamientu del to sitiu. Encamentámos-te de nun tocales demientres que nun tes
 familiarizáu col funcionamientu del sistema SPIP. <br /><br /><b>Más en xeneral, encamentamos
 dexar que s’encargue d’estes páxines el webmaster principal del sitiu.</b>',
	'texte_inc_meta_1' => 'El sistema atopó un error mientres s’escribía el ficheru <code>@fichier@</code>. Como alministrador del sitiu,', # MODIF
	'texte_inc_meta_2' => 'hai que verificar los permisos d’escritura',
	'texte_inc_meta_3' => 'nel direutoriu <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'en cursu de redaición',
	'texte_statut_poubelle' => 'na papelera',
	'texte_statut_propose_evaluation' => 'propuestu pa so evaluación',
	'texte_statut_publie' => 'publicáu en llínia',
	'texte_statut_refuse' => 'refugáu',
	'titre_ajouter_mot_cle' => 'AMESTAR UNA PALLABRA-CLAVE:',
	'titre_cadre_raccourcis' => 'ATAYOS:',
	'titre_changer_couleur_interface' => 'Cambear la color de l’interfaz',
	'titre_image_admin_article' => 'Puedes alministrar esti artículu',
	'titre_image_administrateur' => 'Alministrador', # MODIF
	'titre_image_aide' => 'Aida so esti elementu',
	'titre_image_auteur_supprime' => 'Autor desaniciáu',
	'titre_image_redacteur' => 'Redactor ensin accesu',
	'titre_image_redacteur_02' => 'Redactor',
	'titre_image_visiteur' => 'Visitante',
	'titre_joindre_document' => 'AMESTAR UN DOCUMENTU',
	'titre_mots_cles' => 'PALLABRES-CLAVE',
	'titre_probleme_technique' => 'Atención: por cuenta d’un fallu tecnicu (servidor SQL) ta torgáu l’accesu a esta parte del sitiu web. Fonderes disculpes, encamentámos-te que tornes n’otru momentu.',
	'titre_publier_document' => 'ESPUBLIZAR UN DOCUMENTU NESTA ESTAYA',
	'titre_signatures_attente' => 'Robles n’espera de validación',
	'titre_signatures_confirmees' => 'Robles confirmáes',
	'titre_statistiques' => 'Estadístiques del sitiu',
	'titre_titre_document' => 'Títulu del documentu:',
	'todo' => 'por llegar',
	'trad_reference' => '(artículu orixinal)', # MODIF

	// Z
	'zbug_balise_b_aval' => ' : baliza B detrás',
	'zbug_balise_inexistante' => 'La baliza @balise@ ta mal declarada pa @from@',
	'zbug_balise_sans_argument' => 'Falta un parámetru na baliza @balise@',
	'zbug_boucle' => 'bucle',
	'zbug_boucle_recursive_undef' => 'Bucle recursivu non definíu: @nom@',
	'zbug_calcul' => 'cálculu',
	'zbug_champ_hors_boucle' => 'Campu @champ@ fuera de bucle',
	'zbug_champ_hors_motif' => 'El campu @champ@ ta fuera d’un contestu @motif@',
	'zbug_code' => 'códigu',
	'zbug_critere_inconnu' => 'Criteriu desconocíu @critere@',
	'zbug_distant_interdit' => 'Esternu torgáu',
	'zbug_doublon_table_sans_cle_primaire' => 'Repetíos nuna tabla ensin clave primaria simple',
	'zbug_doublon_table_sans_index' => 'Duplicaos nuna tabla ensin índiz',
	'zbug_erreur_boucle_double' => 'Doble definición del bucle @id@',
	'zbug_erreur_boucle_fermant' => 'El bucle @id@ ta ensin zarrar',
	'zbug_erreur_boucle_syntaxe' => 'Sintaxis del bucle @id@ incorreuta',
	'zbug_erreur_compilation' => 'Error de compilación',
	'zbug_erreur_execution_page' => 'Error d’execución',
	'zbug_erreur_filtre' => 'El filtru @filtre@ nun ta definíu',
	'zbug_erreur_meme_parent' => 'El criteriu {meme_parent} nun s’aplica más que a los bucles (FORUMS) o (RUBRIQUES)',
	'zbug_erreur_squelette' => 'Error(es) na cadarma',
	'zbug_hors_compilation' => 'Fuera de Compilación',
	'zbug_info_erreur_squelette' => 'Error nel sitiu',
	'zbug_inversion_ordre_inexistant' => 'Inversión d’un orde inesistente',
	'zbug_pagination_sans_critere' => 'Baliza #PAGINATION ensin criteriu {pagination} o emplegada nun bucle recursivu',
	'zbug_parametres_inclus_incorrects' => 'Parámetru d’inclusión incorreutu: @param@',
	'zbug_profile' => 'Tiempu pal cálculu: @time@',
	'zbug_resultat' => 'resultáu',
	'zbug_serveur_indefini' => 'Sirvidor SQL indefiníu',
	'zbug_statistiques' => 'Estadístiques de les consultes SQL clasificaes por duración',
	'zbug_table_inconnue' => 'Tabla SQL «@table@» desconocía',
	'zxml_connus_attributs' => 'atributos conocíos',
	'zxml_de' => 'de',
	'zxml_inconnu_attribut' => 'atributu desconocíu',
	'zxml_inconnu_balise' => 'baliza desconocía',
	'zxml_inconnu_entite' => 'entidá desconocía',
	'zxml_inconnu_id' => 'ID desconocía',
	'zxml_mais_de' => 'más de',
	'zxml_non_conforme' => 'nun ye conforme al motivu',
	'zxml_non_fils' => 'nun ye un fiu de',
	'zxml_nonvide_balise' => 'etiqueta non vacía',
	'zxml_obligatoire_attribut' => 'atributu obligatoriu pero que falta en',
	'zxml_succession_fils_incorrecte' => 'sucesión de los fios incorreuta',
	'zxml_survoler' => 'pasar el mur pa ver los correutos',
	'zxml_valeur_attribut' => 'valor de l’atributu',
	'zxml_vide_balise' => 'etiqueta vacía',
	'zxml_vu' => 'visto enantes',
];
